==> wao-ui-1.6-sources.jar: fr/ifremer/wao/ui/pages/IndicatorsHistory.java <==
/*
 * #%L
 * Wao :: Web Interface
 * %%
 * Copyright (C) 2009 - 2010 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;

import fr.ifremer.wao.bean.UserRole;
import fr.ifremer.wao.entity.IndicatorLog;
import fr.ifremer.wao.service.ServiceSynthesis;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import org.apache.tapestry5.annotations.IncludeStylesheet;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.ioc.annotations.Inject;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.List;

/**
 * This page show the list of all modifications done by administrators
 * on the coefficient and bounds between levels since the beginning
 *
 * @author bleny
 */
@RequiresAuthentication(value = {UserRole.ADMIN}, readOnlyAllowed = true)
@IncludeStylesheet("context:css/common.css")
public class IndicatorsHistory {

    @Inject
    private ServiceSynthesis serviceSynthesis;

    private List<IndicatorLog> indicatorLogs;

    /* variable used in template in a loop */
    @Property
    private IndicatorLog indicatorLog;

    public List<IndicatorLog> getIndicatorLogs() {
        if (indicatorLogs == null) {
            indicatorLogs = serviceSynthesis.getAllIndicatorLogs();
        }
        return indicatorLogs;
    }

    public DateFormat getDateFormat() {
        return new SimpleDateFormat("dd/MM/yyyy");
    }
}

==> wao-ui-3.3-sources.jar: fr/ifremer/wao/ui/pages/IndicatorsHistory.java <==
/*
 * #%L
 * Wao :: Web Interface
 * %%
 * Copyright (C) 2009 - 2010 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.wao.ui.pages;

import fr.ifremer.wao.bean.ObsProgram;
import fr.ifremer.wao.bean.UserRole;
import fr.ifremer.wao.entity.IndicatorLog;
import fr.ifremer.wao.service.ServiceSynthesis;
import fr.ifremer.wao.ui.data.RequiresAuthentication;
import org.apache.tapestry5.annotations.Import;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.ioc.annotations.Inject;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.List;

/**
 * This page show the list of all modifications done by administrators
 * on the coefficient and bounds between levels since the beginning
 *
 * @author bleny
 */
@RequiresAuthentication(allowedPrograms = {ObsProgram.OBSMER}, allowedRoles = {UserRole.ADMIN}, readOnlyAllowed = true)
@Import(stylesheet = "context:css/common.css")
public class IndicatorsHistory {

    @Inject
    private ServiceSynthesis serviceSynthesis;

    private List<IndicatorLog> indicatorLogs;

    /* variable used in template in a loop */
    @Property
    private IndicatorLog indicatorLog;

    public List<IndicatorLog> getIndicatorLogs() {
        if (indicatorLogs == null) {
            indicatorLogs = serviceSynthesis.getAllIndicatorLogs();
        }
        return indicatorLogs;
    }

    public DateFormat getDateFormat() {
        return new SimpleDateFormat("dd/MM/yyyy");
    }
}
